import { BaseRoute, fetchOptions, Options } from "./base";
import type { DailyRewardSignInHistoryData, DayRewardData, DailyRewardSignInData, DailyRewardInfoData, DailyRewardExtraRewardData, DailyRewardResignData } from "../interface";
import type { ClientCookieManager } from "../client/clientCookieManager";
export type fetchClaimHistoryOption = fetchOptions & {
    page?: number;
};
declare class RewardInfo extends BaseRoute<DailyRewardInfoData> {
    private readonly defaultOptions?;
    constructor(options?: Options<fetchOptions>);
    /**
     * @description Get the daily rewards info
     */
    fetch(options?: fetchOptions): Promise<DailyRewardInfoData>;
    /**
     * @description Get the daily rewards details
     * @param {number} day Day of the rewards
     */
    fetchDay(day: number, options?: fetchOptions): Promise<DayRewardData>;
}
declare class ExtraRewardInfo extends BaseRoute<DailyRewardExtraRewardData> {
    private readonly defaultOptions?;
    constructor(options?: Options<fetchOptions>);
    /**
     * @description Get the extra rewards info
     */
    fetch(options?: fetchOptions): Promise<DailyRewardExtraRewardData>;
}
declare class ResignInfo extends BaseRoute<DailyRewardResignData> {
    private readonly defaultOptions?;
    constructor(options?: Options<fetchOptions>);
    /**
     * @description get resign info
     */
    fetch(options?: fetchOptions): Promise<DailyRewardResignData>;
}
declare class CheckInHistory extends BaseRoute<DailyRewardSignInHistoryData> {
    private readonly defaultOptions?;
    constructor(options?: Options<fetchOptions>);
    /**
     * @description get check in history
     */
    fetch(options?: fetchClaimHistoryOption): Promise<DailyRewardSignInHistoryData>;
}
export declare class DailyRewards {
    private readonly defaultOptions?;
    readonly cookieManager?: ClientCookieManager;
    rewardInfo: RewardInfo;
    extraRewardInfo: ExtraRewardInfo;
    resignInfo: ResignInfo;
    checkInHistory: CheckInHistory;
    constructor(options?: Options<fetchOptions>);
    /**
     * @description Get the daily rewards details
     * @deprecated use `DailyRewards.dayReward.fetch()` instead
     */
    fetchDayReward(): Promise<DayRewardData>;
    /**
     * @description CheckIn to claim Daily Rewards
     */
    checkIn(options?: fetchOptions): Promise<DailyRewardSignInData>;
    /**
     * @description Get the daily rewards info
     * @deprecated use `DailyRewards.rewardInfo.fetch()` instead
     */
    fetchRewardInfo(): Promise<DailyRewardInfoData>;
    /**
     * @description Get the extra rewards info
     * @deprecated use `DailyRewards.extraReward.fetch()` instead
     */
    fetchExtraRewardInfo(): Promise<DailyRewardExtraRewardData>;
    /**
     * @description get resign info
     * @deprecated use `DailyRewards.resignInfo.fetch()` instead
     */
    fetchResignInfo(): Promise<DailyRewardResignData>;
    /**
     * @description get check in history
     * @deprecated use `DailyRewards.checkInHistory.fetch()` instead
     */
    fetchCheckInHistory(): Promise<DailyRewardSignInHistoryData>;
}
export {};
