"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Activities = void 0;
const base_1 = require("./base");
const utils_1 = require("../utils");
class Activities extends base_1.BaseRoute {
    constructor(options) {
        super(options);
        Object.defineProperty(this, "defaultOptions", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        this.defaultOptions = options?.defaultOptions;
    }
    /**
     * @param {string} uid Genshin Impact UID
     */
    async fetch(uid, options) {
        if (this.cache.has(uid))
            return this.cache.get(uid);
        const optionsToUse = (0, utils_1.mergeOptions)(options, this.cookieManager, this.defaultOptions);
        if (!(0, utils_1.basicValidator)(uid, optionsToUse)) {
            throw new Error("No UID or Cookie provided");
        }
        const { language, cookie } = optionsToUse;
        const instance = new utils_1.RequestManager({
            withDS: true,
            withExtraHeaders: true,
            language,
        });
        const res = await instance.get("activities", {
            Cookie: cookie,
        }, {
            server: (0, utils_1.checkServerRegion)(uid),
            role_id: uid,
        });
        const { data } = res;
        const returnData = {
            sumo: data.activities[0].sumo.records,
            rogue: data.activities[1].rogue.records,
            channeller_slab_copy: data.activities[2].channeller_slab_copy,
            potion: data.activities[3].potion.records,
            sumo_second: data.activities[4].sumo_second.records,
            crystal: data.activities[5].crystal.records,
            perilous: data.activities[6].perilous.records,
            summer_v2: data.activities[7].summer_v2,
            spray: data.activities[8].spray,
        };
        this.cache.set(uid, returnData);
        return returnData;
    }
}
exports.Activities = Activities;
